==> scorchful-0.15.5%2B1.21.4-sources.jar: com/github/thedeathlycow/scorchful/registry/SItemGroups.java <==
package com.github.thedeathlycow.scorchful.registry;

import com.github.thedeathlycow.scorchful.Scorchful;
import com.github.thedeathlycow.scorchful.item.component.DrinkContainerComponent;
import net.fabricmc.fabric.api.itemgroup.v1.FabricItemGroup;
import net.minecraft.class_1761;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_2378;
import net.minecraft.class_2561;
import net.minecraft.class_7923;
import org.jetbrains.annotations.Contract;

public class SItemGroups {
    public static final class_1761 SCORCHFUL = class_2378.method_10230(
            class_7923.field_44687,
            Scorchful.id("main"),
            FabricItemGroup.builder()
                    .method_47320(SItems.SUN_HAT::method_7854)
                    .method_47321(class_2561.method_43471("item_group.scorchful"))
                    .method_47317((context, entries) -> {
                        entries.method_45420(SItems.SUN_HAT.method_7854());
                        entries.method_45420(class_1802.field_8090.method_7854());
                        entries.method_45420(SItems.TURTLE_CHESTPLATE.method_7854());
                        entries.method_45420(SItems.TURTLE_LEGGINGS.method_7854());
                        entries.method_45420(SItems.TURTLE_BOOTS.method_7854());

                        entries.method_45420(SItems.WATER_SKIN.method_7854());
                        entries.method_45420(makeFilledWaterSkin());
                        entries.method_45420(SItems.CACTUS_JUICE.method_7854());

                        entries.method_45420(SItems.CRIMSON_LILY.method_7854());
                        entries.method_45420(SItems.WARPED_LILY.method_7854());
                        entries.method_45420(SItems.ROOTED_NETHERRACK.method_7854());
                        entries.method_45420(SItems. ROOTED_CRIMSON_NYLIUM.method_7854());
                        entries.method_45420(SItems.ROOTED_WARPED_NYLIUM.method_7854());

                        entries.method_45420(SItems.SAND_PILE.method_7854());
                        entries.method_45420(SItems.RED_SAND_PILE.method_7854());
                    }).method_47324()
    );

    public static void initialize() {
        Scorchful.LOGGER.debug("Initialized Scorchful item groups");
    }

    @Contract("->new")
    public static class_1799 makeFilledWaterSkin() {
        var filledWaterSkin = SItems.WATER_SKIN.method_7854();
        DrinkContainerComponent.fillCompletely(filledWaterSkin);
        return filledWaterSkin;
    }

    private SItemGroups() {
    }
}

==> scorchful-0.15.8%2B1.21.1-sources.jar: com/github/thedeathlycow/scorchful/registry/SItemGroups.java <==
package com.github.thedeathlycow.scorchful.registry;

import com.github.thedeathlycow.scorchful.Scorchful;
import com.github.thedeathlycow.scorchful.compat.ScorchfulIntegrations;
import com.github.thedeathlycow.scorchful.item.WaterSkinItem;
import net.fabricmc.fabric.api.itemgroup.v1.FabricItemGroup;
import net.minecraft.class_1761;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_2378;
import net.minecraft.class_2561;
import net.minecraft.class_7923;
import org.jetbrains.annotations.Contract;

public class SItemGroups {
    public static final class_1761 SCORCHFUL = class_2378.method_10230(
            class_7923.field_44687,
            Scorchful.id("main"),
            FabricItemGroup.builder()
                    .method_47320(SItems.SUN_HAT::method_7854)
                    .method_47321(class_2561.method_43471("item_group.scorchful"))
                    .method_47317((context, entries) -> {
                        entries.method_45420(SItems.SUN_HAT.method_7854());
                        entries.method_45420(class_1802.field_8090.method_7854());
                        entries.method_45420(SItems.TURTLE_CHESTPLATE.method_7854());
                        entries.method_45420(SItems.TURTLE_LEGGINGS.method_7854());
                        entries.method_45420(SItems.TURTLE_BOOTS.method_7854());

                        entries.method_45420(SItems.WATER_SKIN.method_7854());
                        entries.method_45420(makeFilledWaterSkin());
                        entries.method_45420(SItems.CACTUS_JUICE.method_7854());

                        entries.method_45420(SItems.CRIMSON_LILY.method_7854());
                        entries.method_45420(SItems.WARPED_LILY.method_7854());
                        entries.method_45420(SItems.ROOTED_NETHERRACK.method_7854());
                        entries.method_45420(SItems.ROOTED_CRIMSON_NYLIUM.method_7854());
                        entries.method_45420(SItems.ROOTED_WARPED_NYLIUM.method_7854());

                        entries.method_45420(SItems.SAND_PILE.method_7854());
                        entries.method_45420(SItems.RED_SAND_PILE.method_7854());
                    }).method_47324()
    );

    public static void initialize() {
        Scorchful.LOGGER.debug("Initialized Scorchful item groups");
    }

    @Contract("->new")
    public static class_1799 makeFilledWaterSkin() {
        var filledWaterSkin = SItems.WATER_SKIN.method_7854();
        WaterSkinItem.addDrinks(filledWaterSkin, WaterSkinItem.MAX_DRINKS);
        return filledWaterSkin;
    }

    private SItemGroups() {
    }
}
